@@ -45,7 +45,7 @@ impl IpRelMemOpInstr {
 		}
 	}
 
-	fn try_optimize<'a>(&mut self, base: &mut InstrBase, ctx: &mut InstrContext<'a>, gained: u64) -> bool {
+	fn try_optimize(&mut self, base: &mut InstrBase, ctx: &mut InstrContext<'_>, gained: u64) -> bool {
 		if self.instr_kind == InstrKind::Unchanged || self.instr_kind == InstrKind::Rip || self.instr_kind == InstrKind::Eip {
 			base.done = true;
 			return false;
@@ -68,7 +68,7 @@ impl IpRelMemOpInstr {
 			return true;
 		}
 
-		// If it's in the lower 4GB we can use EIP relative addressing
+		// If it's in the low 4GB we can use EIP relative addressing
 		if target_address <= u32::MAX as u64 {
 			base.size = self.eip_instruction_size as u32;
 			self.instr_kind = InstrKind::Eip;
@@ -86,11 +86,11 @@ impl Instr for IpRelMemOpInstr {
 		(&mut self.target_instr, self.instruction.ip_rel_memory_address())
 	}
 
-	fn optimize<'a>(&mut self, base: &mut InstrBase, ctx: &mut InstrContext<'a>, gained: u64) -> bool {
+	fn optimize(&mut self, base: &mut InstrBase, ctx: &mut InstrContext<'_>, gained: u64) -> bool {
 		self.try_optimize(base, ctx, gained)
 	}
 
-	fn encode<'a>(&mut self, _base: &mut InstrBase, ctx: &mut InstrContext<'a>) -> Result<(ConstantOffsets, bool), IcedError> {
+	fn encode(&mut self, _base: &mut InstrBase, ctx: &mut InstrContext<'_>) -> Result<(ConstantOffsets, bool), IcedError> {
 		match self.instr_kind {
 			InstrKind::Unchanged | InstrKind::Rip | InstrKind::Eip => {
 				if self.instr_kind == InstrKind::Rip {
@@ -113,7 +113,7 @@ impl Instr for IpRelMemOpInstr {
 							Ok((ctx.block.encoder.get_constant_offsets(), true))
 						}
 					}
-					Err(err) => Err(IcedError::with_string(InstrUtils::create_error_message(&err, &self.instruction))),
+					Err(err) => Err(IcedError::with_string(InstrUtils::create_error_message(err, &self.instruction))),
 				}
 			}
 
