@@ -17,6 +17,7 @@ enum InstrKind {
 }
 
 pub(super) struct JmpInstr {
+	bitness: u8,
 	instruction: Instruction,
 	target_instr: TargetInstr,
 	pointer_data: Option<Rc<RefCell<BlockData>>>,
@@ -57,6 +58,7 @@ impl JmpInstr {
 			} as u32
 		}
 		Self {
+			bitness: block_encoder.bitness() as u8,
 			instruction: *instruction,
 			target_instr: TargetInstr::default(),
 			pointer_data: None,
@@ -66,7 +68,7 @@ impl JmpInstr {
 		}
 	}
 
-	fn try_optimize<'a>(&mut self, base: &mut InstrBase, ctx: &mut InstrContext<'a>, gained: u64) -> bool {
+	fn try_optimize(&mut self, base: &mut InstrBase, ctx: &mut InstrContext<'_>, gained: u64) -> bool {
 		if self.instr_kind == InstrKind::Unchanged || self.instr_kind == InstrKind::Short {
 			base.done = true;
 			return false;
@@ -75,7 +77,7 @@ impl JmpInstr {
 		let mut target_address = self.target_instr.address(ctx);
 		let mut next_rip = ctx.ip.wrapping_add(self.short_instruction_size as u64);
 		let mut diff = target_address.wrapping_sub(next_rip) as i64;
-		diff = correct_diff(self.target_instr.is_in_block(ctx.block), diff, gained);
+		diff = InstrUtils::convert_diff_to_bitness_diff(self.bitness, correct_diff(self.target_instr.is_in_block(ctx.block), diff, gained));
 		if i8::MIN as i64 <= diff && diff <= i8::MAX as i64 {
 			if let Some(ref pointer_data) = self.pointer_data {
 				pointer_data.borrow_mut().is_valid = false;
@@ -86,11 +88,15 @@ impl JmpInstr {
 			return true;
 		}
 
-		target_address = self.target_instr.address(ctx);
-		next_rip = ctx.ip.wrapping_add(self.near_instruction_size as u64);
-		diff = target_address.wrapping_sub(next_rip) as i64;
-		diff = correct_diff(self.target_instr.is_in_block(ctx.block), diff, gained);
-		let use_near = i32::MIN as i64 <= diff && diff <= i32::MAX as i64;
+		// If it's in the same block, we assume the target is at most 2GB away.
+		let mut use_near = self.bitness != 64 || self.target_instr.is_in_block(ctx.block);
+		if !use_near {
+			target_address = self.target_instr.address(ctx);
+			next_rip = ctx.ip.wrapping_add(self.near_instruction_size as u64);
+			diff = target_address.wrapping_sub(next_rip) as i64;
+			diff = InstrUtils::convert_diff_to_bitness_diff(self.bitness, correct_diff(self.target_instr.is_in_block(ctx.block), diff, gained));
+			use_near = i32::MIN as i64 <= diff && diff <= i32::MAX as i64;
+		}
 		if use_near {
 			if let Some(ref pointer_data) = self.pointer_data {
 				pointer_data.borrow_mut().is_valid = false;
@@ -118,11 +124,11 @@ impl Instr for JmpInstr {
 		(&mut self.target_instr, self.instruction.near_branch_target())
 	}
 
-	fn optimize<'a>(&mut self, base: &mut InstrBase, ctx: &mut InstrContext<'a>, gained: u64) -> bool {
+	fn optimize(&mut self, base: &mut InstrBase, ctx: &mut InstrContext<'_>, gained: u64) -> bool {
 		self.try_optimize(base, ctx, gained)
 	}
 
-	fn encode<'a>(&mut self, base: &mut InstrBase, ctx: &mut InstrContext<'a>) -> Result<(ConstantOffsets, bool), IcedError> {
+	fn encode(&mut self, base: &mut InstrBase, ctx: &mut InstrContext<'_>) -> Result<(ConstantOffsets, bool), IcedError> {
 		match self.instr_kind {
 			InstrKind::Unchanged | InstrKind::Short | InstrKind::Near => {
 				if self.instr_kind == InstrKind::Unchanged {
@@ -135,7 +141,7 @@ impl Instr for JmpInstr {
 				}
 				self.instruction.set_near_branch64(self.target_instr.address(ctx));
 				ctx.block.encoder.encode(&self.instruction, ctx.ip).map_or_else(
-					|err| Err(IcedError::with_string(InstrUtils::create_error_message(&err, &self.instruction))),
+					|err| Err(IcedError::with_string(InstrUtils::create_error_message(err, &self.instruction))),
 					|_| Ok((ctx.block.encoder.get_constant_offsets(), true)),
 				)
 			}
@@ -145,7 +151,7 @@ impl Instr for JmpInstr {
 				let pointer_data = self.pointer_data.clone().ok_or_else(|| IcedError::new("Internal error"))?;
 				pointer_data.borrow_mut().data = self.target_instr.address(ctx);
 				InstrUtils::encode_branch_to_pointer_data(ctx.block, false, ctx.ip, pointer_data, base.size).map_or_else(
-					|err| Err(IcedError::with_string(InstrUtils::create_error_message(&err, &self.instruction))),
+					|err| Err(IcedError::with_string(InstrUtils::create_error_message(err, &self.instruction))),
 					|_| Ok((ConstantOffsets::default(), false)),
 				)
 			}
