@@ -17,6 +17,7 @@ enum InstrKind {
 }
 
 pub(super) struct SimpleBranchInstr {
+	bitness: u8,
 	instruction: Instruction,
 	target_instr: TargetInstr,
 	pointer_data: Option<Rc<RefCell<BlockData>>>,
@@ -77,6 +78,7 @@ impl SimpleBranchInstr {
 			} as u32;
 		}
 		Self {
+			bitness: block_encoder.bitness() as u8,
 			instruction: *instruction,
 			target_instr: TargetInstr::default(),
 			pointer_data: None,
@@ -89,7 +91,7 @@ impl SimpleBranchInstr {
 		}
 	}
 
-	fn try_optimize<'a>(&mut self, base: &mut InstrBase, ctx: &mut InstrContext<'a>, gained: u64) -> bool {
+	fn try_optimize(&mut self, base: &mut InstrBase, ctx: &mut InstrContext<'_>, gained: u64) -> bool {
 		if self.instr_kind == InstrKind::Unchanged || self.instr_kind == InstrKind::Short {
 			base.done = true;
 			return false;
@@ -98,7 +100,7 @@ impl SimpleBranchInstr {
 		let mut target_address = self.target_instr.address(ctx);
 		let mut next_rip = ctx.ip.wrapping_add(self.short_instruction_size as u64);
 		let mut diff = target_address.wrapping_sub(next_rip) as i64;
-		diff = correct_diff(self.target_instr.is_in_block(ctx.block), diff, gained);
+		diff = InstrUtils::convert_diff_to_bitness_diff(self.bitness, correct_diff(self.target_instr.is_in_block(ctx.block), diff, gained));
 		if i8::MIN as i64 <= diff && diff <= i8::MAX as i64 {
 			if let Some(ref pointer_data) = self.pointer_data {
 				pointer_data.borrow_mut().is_valid = false;
@@ -109,11 +111,15 @@ impl SimpleBranchInstr {
 			return true;
 		}
 
-		target_address = self.target_instr.address(ctx);
-		next_rip = ctx.ip.wrapping_add(self.near_instruction_size as u64);
-		diff = target_address.wrapping_sub(next_rip) as i64;
-		diff = correct_diff(self.target_instr.is_in_block(ctx.block), diff, gained);
-		let use_near = i32::MIN as i64 <= diff && diff <= i32::MAX as i64;
+		// If it's in the same block, we assume the target is at most 2GB away.
+		let mut use_near = self.bitness != 64 || self.target_instr.is_in_block(ctx.block);
+		if !use_near {
+			target_address = self.target_instr.address(ctx);
+			next_rip = ctx.ip.wrapping_add(self.near_instruction_size as u64);
+			diff = target_address.wrapping_sub(next_rip) as i64;
+			diff = InstrUtils::convert_diff_to_bitness_diff(self.bitness, correct_diff(self.target_instr.is_in_block(ctx.block), diff, gained));
+			use_near = i32::MIN as i64 <= diff && diff <= i32::MAX as i64;
+		}
 		if use_near {
 			if let Some(ref pointer_data) = self.pointer_data {
 				pointer_data.borrow_mut().is_valid = false;
@@ -172,11 +178,11 @@ impl Instr for SimpleBranchInstr {
 		(&mut self.target_instr, self.instruction.near_branch_target())
 	}
 
-	fn optimize<'a>(&mut self, base: &mut InstrBase, ctx: &mut InstrContext<'a>, gained: u64) -> bool {
+	fn optimize(&mut self, base: &mut InstrBase, ctx: &mut InstrContext<'_>, gained: u64) -> bool {
 		self.try_optimize(base, ctx, gained)
 	}
 
-	fn encode<'a>(&mut self, base: &mut InstrBase, ctx: &mut InstrContext<'a>) -> Result<(ConstantOffsets, bool), IcedError> {
+	fn encode(&mut self, base: &mut InstrBase, ctx: &mut InstrContext<'_>) -> Result<(ConstantOffsets, bool), IcedError> {
 		let mut instr;
 		let mut size;
 		let instr_len;
@@ -184,7 +190,7 @@ impl Instr for SimpleBranchInstr {
 			InstrKind::Unchanged | InstrKind::Short => {
 				self.instruction.set_near_branch64(self.target_instr.address(ctx));
 				ctx.block.encoder.encode(&self.instruction, ctx.ip).map_or_else(
-					|err| Err(IcedError::with_string(InstrUtils::create_error_message(&err, &self.instruction))),
+					|err| Err(IcedError::with_string(InstrUtils::create_error_message(err, &self.instruction))),
 					|_| Ok((ctx.block.encoder.get_constant_offsets(), true)),
 				)
 			}
@@ -204,7 +210,7 @@ impl Instr for SimpleBranchInstr {
 					.block
 					.encoder
 					.encode(&instr, ctx.ip)
-					.map_err(|err| IcedError::with_string(InstrUtils::create_error_message(&err, &self.instruction)))? as u32;
+					.map_err(|err| IcedError::with_string(InstrUtils::create_error_message(err, &self.instruction)))? as u32;
 
 				instr = Instruction::default();
 				instr.set_near_branch64(ctx.ip.wrapping_add(self.near_instruction_size as u64));
@@ -233,13 +239,13 @@ impl Instr for SimpleBranchInstr {
 					.block
 					.encoder
 					.encode(&instr, ctx.ip.wrapping_add(size as u64))
-					.map_err(|err| IcedError::with_string(InstrUtils::create_error_message(&err, &self.instruction)))? as u32;
+					.map_err(|err| IcedError::with_string(InstrUtils::create_error_message(err, &self.instruction)))? as u32;
 				size += instr_len;
 
 				instr.set_code(code_near);
 				instr.set_near_branch64(self.target_instr.address(ctx));
 				ctx.block.encoder.encode(&instr, ctx.ip.wrapping_add(size as u64)).map_or_else(
-					|err| Err(IcedError::with_string(InstrUtils::create_error_message(&err, &self.instruction))),
+					|err| Err(IcedError::with_string(InstrUtils::create_error_message(err, &self.instruction))),
 					|_| Ok((ConstantOffsets::default(), false)),
 				)
 			}
@@ -264,7 +270,7 @@ impl Instr for SimpleBranchInstr {
 					.block
 					.encoder
 					.encode(&instr, ctx.ip)
-					.map_err(|err| IcedError::with_string(InstrUtils::create_error_message(&err, &self.instruction)))? as u32;
+					.map_err(|err| IcedError::with_string(InstrUtils::create_error_message(err, &self.instruction)))? as u32;
 
 				instr = Instruction::default();
 				instr.set_near_branch64(ctx.ip.wrapping_add(self.long_instruction_size as u64));
@@ -290,7 +296,7 @@ impl Instr for SimpleBranchInstr {
 					.block
 					.encoder
 					.encode(&instr, ctx.ip.wrapping_add(size as u64))
-					.map_err(|err| IcedError::with_string(InstrUtils::create_error_message(&err, &self.instruction)))? as u32;
+					.map_err(|err| IcedError::with_string(InstrUtils::create_error_message(err, &self.instruction)))? as u32;
 				size += instr_len;
 
 				InstrUtils::encode_branch_to_pointer_data(
@@ -301,7 +307,7 @@ impl Instr for SimpleBranchInstr {
 					base.size.wrapping_sub(size),
 				)
 				.map_or_else(
-					|err| Err(IcedError::with_string(InstrUtils::create_error_message(&err, &self.instruction))),
+					|err| Err(IcedError::with_string(InstrUtils::create_error_message(err, &self.instruction))),
 					|_| Ok((ConstantOffsets::default(), false)),
 				)
 			}
