@@ -23,13 +23,13 @@ impl Instr for SimpleInstr {
 		unreachable!()
 	}
 
-	fn optimize<'a>(&mut self, _base: &mut InstrBase, _ctx: &mut InstrContext<'a>, _gained: u64) -> bool {
+	fn optimize(&mut self, _base: &mut InstrBase, _ctx: &mut InstrContext<'_>, _gained: u64) -> bool {
 		false
 	}
 
-	fn encode<'a>(&mut self, _base: &mut InstrBase, ctx: &mut InstrContext<'a>) -> Result<(ConstantOffsets, bool), IcedError> {
+	fn encode(&mut self, _base: &mut InstrBase, ctx: &mut InstrContext<'_>) -> Result<(ConstantOffsets, bool), IcedError> {
 		ctx.block.encoder.encode(&self.instruction, ctx.ip).map_or_else(
-			|err| Err(IcedError::with_string(InstrUtils::create_error_message(&err, &self.instruction))),
+			|err| Err(IcedError::with_string(InstrUtils::create_error_message(err, &self.instruction))),
 			|_| Ok((ctx.block.encoder.get_constant_offsets(), true)),
 		)
 	}
