@@ -4,8 +4,8 @@
 macro_rules! mk_read_xx {
 	($slf:ident, $mem_ty:ty, $from_le:path, $ret_ty:ty, $err_expr:expr) => {
 		const SIZE: usize = mem::size_of::<$mem_ty>();
-		const_assert!(SIZE >= 1);
-		const_assert!(SIZE <= Decoder::MAX_READ_SIZE);
+		const _: () = assert!(SIZE >= 1);
+		const _: () = assert!(SIZE <= Decoder::MAX_READ_SIZE);
 		let data_ptr = $slf.data_ptr;
 		#[allow(trivial_numeric_casts)]
 		{
@@ -100,10 +100,8 @@ use crate::iced_error::IcedError;
 use crate::instruction_internal;
 use crate::tuple_type_tbl::get_disp8n;
 use crate::*;
-use core::convert::TryFrom;
 use core::iter::FusedIterator;
 use core::{cmp, fmt, mem, ptr};
-use static_assertions::{const_assert, const_assert_eq};
 
 #[rustfmt::skip]
 #[cfg(any(feature = "__internal_flip", not(feature = "no_evex"), not(feature = "no_vex"), not(feature = "no_xop"), feature = "mvex"))]
@@ -269,9 +267,8 @@ fn test_decodererror_try_from_usize() {
 #[rustfmt::skip]
 #[allow(clippy::zero_sized_map_values)]
 const _: () = {
-	use alloc::string::String;
 	use core::marker::PhantomData;
-	use serde::de::{self, VariantAccess};
+	use serde::de;
 	use serde::{Deserialize, Deserializer, Serialize, Serializer};
 	type EnumType = DecoderError;
 	impl Serialize for EnumType {
@@ -280,7 +277,7 @@ const _: () = {
 		where
 			S: Serializer,
 		{
-			serializer.serialize_unit_variant("DecoderError", *self as u32, GEN_DEBUG_DECODER_ERROR[*self as usize])
+			serializer.serialize_u8(*self as u8)
 		}
 	}
 	impl<'de> Deserialize<'de> for EnumType {
@@ -289,65 +286,6 @@ const _: () = {
 		where
 			D: Deserializer<'de>,
 		{
-			#[repr(transparent)]
-			struct EnumValue(EnumType);
-			struct EnumValueVisitor;
-			impl<'de> de::Visitor<'de> for EnumValueVisitor {
-				type Value = EnumValue;
-				#[inline]
-				fn expecting(&self, formatter: &mut fmt::Formatter<'_>) -> fmt::Result {
-					formatter.write_str("variant identifier")
-				}
-				#[inline]
-				fn visit_u64<E>(self, v: u64) -> Result<Self::Value, E>
-				where
-					E: de::Error,
-				{
-					if let Ok(v) = <usize as TryFrom<_>>::try_from(v) {
-						if let Ok(value) = <EnumType as TryFrom<_>>::try_from(v) {
-							return Ok(EnumValue(value));
-						}
-					}
-					Err(de::Error::invalid_value(de::Unexpected::Unsigned(v), &"a valid DecoderError variant value"))
-				}
-				#[inline]
-				fn visit_str<E>(self, v: &str) -> Result<Self::Value, E>
-				where
-					E: de::Error,
-				{
-					EnumValueVisitor::deserialize_name(v.as_bytes())
-				}
-				#[inline]
-				fn visit_bytes<E>(self, v: &[u8]) -> Result<Self::Value, E>
-				where
-					E: de::Error,
-				{
-					EnumValueVisitor::deserialize_name(v)
-				}
-			}
-			impl EnumValueVisitor {
-				#[inline]
-				fn deserialize_name<E>(v: &[u8]) -> Result<EnumValue, E>
-				where
-					E: de::Error,
-				{
-					for (&name, value) in GEN_DEBUG_DECODER_ERROR.iter().zip(EnumType::values()) {
-						if name.as_bytes() == v {
-							return Ok(EnumValue(value));
-						}
-					}
-					Err(de::Error::unknown_variant(&String::from_utf8_lossy(v), &["DecoderError enum variants"][..]))
-				}
-			}
-			impl<'de> Deserialize<'de> for EnumValue {
-				#[inline]
-				fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
-				where
-					D: Deserializer<'de>,
-				{
-					deserializer.deserialize_identifier(EnumValueVisitor)
-				}
-			}
 			struct Visitor<'de> {
 				marker: PhantomData<EnumType>,
 				lifetime: PhantomData<&'de ()>,
@@ -359,18 +297,19 @@ const _: () = {
 					formatter.write_str("enum DecoderError")
 				}
 				#[inline]
-				fn visit_enum<A>(self, data: A) -> Result<Self::Value, A::Error>
+				fn visit_u64<E>(self, v: u64) -> Result<Self::Value, E>
 				where
-					A: de::EnumAccess<'de>,
+					E: de::Error,
 				{
-					let (field, variant): (EnumValue, _) = data.variant()?;
-					match variant.unit_variant() {
-						Ok(_) => Ok(field.0),
-						Err(err) => Err(err),
+					if let Ok(v) = <usize as TryFrom<_>>::try_from(v) {
+						if let Ok(value) = <EnumType as TryFrom<_>>::try_from(v) {
+							return Ok(value);
+						}
 					}
+					Err(de::Error::invalid_value(de::Unexpected::Unsigned(v), &"a valid DecoderError variant value"))
 				}
 			}
-			deserializer.deserialize_enum("DecoderError", &GEN_DEBUG_DECODER_ERROR[..], Visitor { marker: PhantomData::<EnumType>, lifetime: PhantomData })
+			deserializer.deserialize_u8(Visitor { marker: PhantomData::<EnumType>, lifetime: PhantomData })
 		}
 	}
 };
@@ -537,7 +476,7 @@ impl State {
 	#[must_use]
 	#[inline(always)]
 	#[cfg(debug_assertions)]
-	fn encoding(&self) -> u32 {
+	const fn encoding(&self) -> u32 {
 		(self.flags >> StateFlags::ENCODING_SHIFT) & StateFlags::ENCODING_MASK
 	}
 
@@ -1100,7 +1039,7 @@ impl<'a> Decoder<'a> {
 	/// [`position()`]: #method.position
 	#[must_use]
 	#[inline]
-	pub fn ip(&self) -> u64 {
+	pub const fn ip(&self) -> u64 {
 		self.ip
 	}
 
@@ -1121,7 +1060,7 @@ impl<'a> Decoder<'a> {
 	/// Gets the bitness (16, 32 or 64)
 	#[must_use]
 	#[inline]
-	pub fn bitness(&self) -> u32 {
+	pub const fn bitness(&self) -> u32 {
 		self.bitness
 	}
 
@@ -1131,7 +1070,7 @@ impl<'a> Decoder<'a> {
 	/// [`try_set_position()`]: #method.try_set_position
 	#[must_use]
 	#[inline]
-	pub fn max_position(&self) -> usize {
+	pub const fn max_position(&self) -> usize {
 		self.data.len()
 	}
 
@@ -1246,6 +1185,7 @@ impl<'a> Decoder<'a> {
 	/// ```
 	#[must_use]
 	#[inline]
+	#[allow(clippy::missing_const_for_fn)]
 	pub fn can_decode(&self) -> bool {
 		self.data_ptr != self.data_ptr_end
 	}
@@ -1317,7 +1257,7 @@ impl<'a> Decoder<'a> {
 	/// [`instruction.is_invalid()`]: struct.Instruction.html#method.is_invalid
 	#[must_use]
 	#[inline]
-	pub fn last_error(&self) -> DecoderError {
+	pub const fn last_error(&self) -> DecoderError {
 		// NoMoreBytes error has highest priority
 		if (self.state.flags & StateFlags::NO_MORE_BYTES) != 0 {
 			DecoderError::NoMoreBytes
@@ -1509,7 +1449,7 @@ impl<'a> Decoder<'a> {
 				|| (((flags & (StateFlags::LOCK | StateFlags::ALLOW_LOCK)) & self.invalid_check_mask) == StateFlags::LOCK)
 			{
 				*instruction = Instruction::default();
-				const_assert_eq!(Code::INVALID as u32, 0);
+				const _: () = assert!(Code::INVALID as u32 == 0);
 				//instruction.set_code(Code::INVALID);
 
 				if (flags & StateFlags::NO_MORE_BYTES) != 0 {
@@ -1648,7 +1588,7 @@ impl<'a> Decoder<'a> {
 
 	#[cfg(not(feature = "no_vex"))]
 	fn vex2(&mut self, instruction: &mut Instruction) {
-		const_assert_eq!(DecoderMandatoryPrefix::PNP as u32, 0);
+		const _: () = assert!(DecoderMandatoryPrefix::PNP as u32 == 0);
 		if (((self.state.flags & StateFlags::HAS_REX) | (self.state.mandatory_prefix as u32)) & self.invalid_check_mask) != 0 {
 			self.set_invalid_instruction();
 		}
@@ -1666,16 +1606,16 @@ impl<'a> Decoder<'a> {
 
 		let mut b = self.state.modrm;
 
-		const_assert_eq!(VectorLength::L128 as u32, 0);
-		const_assert_eq!(VectorLength::L256 as u32, 1);
-		// SAFETY: 0<=(n&1)<=1 and those are valid enum variants, see const_assert_eq!() above
+		const _: () = assert!(VectorLength::L128 as u32 == 0);
+		const _: () = assert!(VectorLength::L256 as u32 == 1);
+		// SAFETY: 0<=(n&1)<=1 and those are valid enum variants, see const assert!() above
 		self.state.vector_length = unsafe { mem::transmute((b >> 2) & 1) };
 
-		const_assert_eq!(DecoderMandatoryPrefix::PNP as u32, 0);
-		const_assert_eq!(DecoderMandatoryPrefix::P66 as u32, 1);
-		const_assert_eq!(DecoderMandatoryPrefix::PF3 as u32, 2);
-		const_assert_eq!(DecoderMandatoryPrefix::PF2 as u32, 3);
-		// SAFETY: 0<=(b&3)<=3 and those are valid enum variants, see const_assert_eq!() above
+		const _: () = assert!(DecoderMandatoryPrefix::PNP as u32 == 0);
+		const _: () = assert!(DecoderMandatoryPrefix::P66 as u32 == 1);
+		const _: () = assert!(DecoderMandatoryPrefix::PF3 as u32 == 2);
+		const _: () = assert!(DecoderMandatoryPrefix::PF2 as u32 == 3);
+		// SAFETY: 0<=(b&3)<=3 and those are valid enum variants, see const assert!() above
 		self.state.mandatory_prefix = unsafe { mem::transmute(b & 3) };
 
 		b = !b;
@@ -1696,7 +1636,7 @@ impl<'a> Decoder<'a> {
 
 	#[cfg(not(feature = "no_vex"))]
 	fn vex3(&mut self, instruction: &mut Instruction) {
-		const_assert_eq!(DecoderMandatoryPrefix::PNP as u32, 0);
+		const _: () = assert!(DecoderMandatoryPrefix::PNP as u32 == 0);
 		if (((self.state.flags & StateFlags::HAS_REX) | (self.state.mandatory_prefix as u32)) & self.invalid_check_mask) != 0 {
 			self.set_invalid_instruction();
 		}
@@ -1709,19 +1649,19 @@ impl<'a> Decoder<'a> {
 
 		let b2 = self.read_u16() as u32;
 
-		const_assert_eq!(StateFlags::W, 0x80);
+		const _: () = assert!(StateFlags::W == 0x80);
 		self.state.flags |= b2 & 0x80;
 
-		const_assert_eq!(VectorLength::L128 as u32, 0);
-		const_assert_eq!(VectorLength::L256 as u32, 1);
-		// SAFETY: 0<=(n&1)<=1 and those are valid enum variants, see const_assert_eq!() above
+		const _: () = assert!(VectorLength::L128 as u32 == 0);
+		const _: () = assert!(VectorLength::L256 as u32 == 1);
+		// SAFETY: 0<=(n&1)<=1 and those are valid enum variants, see const assert!() above
 		self.state.vector_length = unsafe { mem::transmute((b2 >> 2) & 1) };
 
-		const_assert_eq!(DecoderMandatoryPrefix::PNP as u32, 0);
-		const_assert_eq!(DecoderMandatoryPrefix::P66 as u32, 1);
-		const_assert_eq!(DecoderMandatoryPrefix::PF3 as u32, 2);
-		const_assert_eq!(DecoderMandatoryPrefix::PF2 as u32, 3);
-		// SAFETY: 0<=(b2&3)<=3 and those are valid enum variants, see const_assert_eq!() above
+		const _: () = assert!(DecoderMandatoryPrefix::PNP as u32 == 0);
+		const _: () = assert!(DecoderMandatoryPrefix::P66 as u32 == 1);
+		const _: () = assert!(DecoderMandatoryPrefix::PF3 as u32 == 2);
+		const _: () = assert!(DecoderMandatoryPrefix::PF2 as u32 == 3);
+		// SAFETY: 0<=(b2&3)<=3 and those are valid enum variants, see const assert!() above
 		self.state.mandatory_prefix = unsafe { mem::transmute(b2 & 3) };
 
 		let b = (!b2 >> 3) & 0x0F;
@@ -1752,7 +1692,7 @@ impl<'a> Decoder<'a> {
 
 	#[cfg(not(feature = "no_xop"))]
 	fn xop(&mut self, instruction: &mut Instruction) {
-		const_assert_eq!(DecoderMandatoryPrefix::PNP as u32, 0);
+		const _: () = assert!(DecoderMandatoryPrefix::PNP as u32 == 0);
 		if (((self.state.flags & StateFlags::HAS_REX) | (self.state.mandatory_prefix as u32)) & self.invalid_check_mask) != 0 {
 			self.set_invalid_instruction();
 		}
@@ -1765,19 +1705,19 @@ impl<'a> Decoder<'a> {
 
 		let b2 = self.read_u16() as u32;
 
-		const_assert_eq!(StateFlags::W, 0x80);
+		const _: () = assert!(StateFlags::W == 0x80);
 		self.state.flags |= b2 & 0x80;
 
-		const_assert_eq!(VectorLength::L128 as u32, 0);
-		const_assert_eq!(VectorLength::L256 as u32, 1);
-		// SAFETY: 0<=(n&1)<=1 and those are valid enum variants, see const_assert_eq!() above
+		const _: () = assert!(VectorLength::L128 as u32 == 0);
+		const _: () = assert!(VectorLength::L256 as u32 == 1);
+		// SAFETY: 0<=(n&1)<=1 and those are valid enum variants, see const assert!() above
 		self.state.vector_length = unsafe { mem::transmute((b2 >> 2) & 1) };
 
-		const_assert_eq!(DecoderMandatoryPrefix::PNP as u32, 0);
-		const_assert_eq!(DecoderMandatoryPrefix::P66 as u32, 1);
-		const_assert_eq!(DecoderMandatoryPrefix::PF3 as u32, 2);
-		const_assert_eq!(DecoderMandatoryPrefix::PF2 as u32, 3);
-		// SAFETY: 0<=(b2&3)<=3 and those are valid enum variants, see const_assert_eq!() above
+		const _: () = assert!(DecoderMandatoryPrefix::PNP as u32 == 0);
+		const _: () = assert!(DecoderMandatoryPrefix::P66 as u32 == 1);
+		const _: () = assert!(DecoderMandatoryPrefix::PF3 as u32 == 2);
+		const _: () = assert!(DecoderMandatoryPrefix::PF2 as u32 == 3);
+		// SAFETY: 0<=(b2&3)<=3 and those are valid enum variants, see const assert!() above
 		self.state.mandatory_prefix = unsafe { mem::transmute(b2 & 3) };
 
 		let b = (!b2 >> 3) & 0x0F;
@@ -1803,7 +1743,7 @@ impl<'a> Decoder<'a> {
 
 	#[cfg(any(not(feature = "no_evex"), feature = "mvex"))]
 	fn evex_mvex(&mut self, instruction: &mut Instruction) {
-		const_assert_eq!(DecoderMandatoryPrefix::PNP as u32, 0);
+		const _: () = assert!(DecoderMandatoryPrefix::PNP as u32 == 0);
 		if (((self.state.flags & StateFlags::HAS_REX) | (self.state.mandatory_prefix as u32)) & self.invalid_check_mask) != 0 {
 			self.set_invalid_instruction();
 		}
@@ -1822,14 +1762,14 @@ impl<'a> Decoder<'a> {
 						self.state.flags |= (EncodingKind::EVEX as u32) << StateFlags::ENCODING_SHIFT;
 					}
 
-					const_assert_eq!(DecoderMandatoryPrefix::PNP as u32, 0);
-					const_assert_eq!(DecoderMandatoryPrefix::P66 as u32, 1);
-					const_assert_eq!(DecoderMandatoryPrefix::PF3 as u32, 2);
-					const_assert_eq!(DecoderMandatoryPrefix::PF2 as u32, 3);
-					// SAFETY: 0<=(d&3)<=3 and those are valid enum variants, see const_assert_eq!() above
+					const _: () = assert!(DecoderMandatoryPrefix::PNP as u32 == 0);
+					const _: () = assert!(DecoderMandatoryPrefix::P66 as u32 == 1);
+					const _: () = assert!(DecoderMandatoryPrefix::PF3 as u32 == 2);
+					const _: () = assert!(DecoderMandatoryPrefix::PF2 as u32 == 3);
+					// SAFETY: 0<=(d&3)<=3 and those are valid enum variants, see const assert!() above
 					self.state.mandatory_prefix = unsafe { mem::transmute(d & 3) };
 
-					const_assert_eq!(StateFlags::W, 0x80);
+					const _: () = assert!(StateFlags::W == 0x80);
 					self.state.flags |= d & 0x80;
 
 					let p2 = d >> 8;
@@ -1845,14 +1785,14 @@ impl<'a> Decoder<'a> {
 						instruction.set_zeroing_masking(true);
 					}
 
-					const_assert_eq!(StateFlags::B, 0x10);
+					const _: () = assert!(StateFlags::B == 0x10);
 					self.state.flags |= p2 & 0x10;
 
-					const_assert_eq!(VectorLength::L128 as u32, 0);
-					const_assert_eq!(VectorLength::L256 as u32, 1);
-					const_assert_eq!(VectorLength::L512 as u32, 2);
-					const_assert_eq!(VectorLength::Unknown as u32, 3);
-					// SAFETY: 0<=(n&3)<=3 and those are valid enum variants, see const_assert_eq!() above
+					const _: () = assert!(VectorLength::L128 as u32 == 0);
+					const _: () = assert!(VectorLength::L256 as u32 == 1);
+					const _: () = assert!(VectorLength::L512 as u32 == 2);
+					const _: () = assert!(VectorLength::Unknown as u32 == 3);
+					// SAFETY: 0<=(n&3)<=3 and those are valid enum variants, see const assert!() above
 					self.state.vector_length = unsafe { mem::transmute((p2 >> 5) & 3) };
 
 					let p1 = (!d >> 3) & 0x0F;
@@ -1872,7 +1812,7 @@ impl<'a> Decoder<'a> {
 					} else {
 						self.state.vvvv_invalid_check = p1;
 						self.state.vvvv = p1 & 0x07;
-						const_assert_eq!(StateFlags::IS_INVALID, 0x40);
+						const _: () = assert!(StateFlags::IS_INVALID == 0x40);
 						self.state.flags |= (!p2 & 8) << 3;
 					}
 
@@ -1886,7 +1826,7 @@ impl<'a> Decoder<'a> {
 						self.state.rm = m & 7;
 						self.state.mem_index = (self.state.mod_ << 3) | self.state.rm;
 						// Invalid if LL=3 and no rc
-						const_assert!(StateFlags::B > 3);
+						const _: () = assert!(StateFlags::B > 3);
 						debug_assert!(self.state.vector_length as u32 <= 3);
 						if (((self.state.flags & StateFlags::B) | (self.state.vector_length as u32)) & self.invalid_check_mask) == 3 {
 							self.set_invalid_instruction();
@@ -1912,14 +1852,14 @@ impl<'a> Decoder<'a> {
 						self.state.flags |= (EncodingKind::MVEX as u32) << StateFlags::ENCODING_SHIFT;
 					}
 
-					const_assert_eq!(DecoderMandatoryPrefix::PNP as u32, 0);
-					const_assert_eq!(DecoderMandatoryPrefix::P66 as u32, 1);
-					const_assert_eq!(DecoderMandatoryPrefix::PF3 as u32, 2);
-					const_assert_eq!(DecoderMandatoryPrefix::PF2 as u32, 3);
-					// SAFETY: 0<=(d&3)<=3 and those are valid enum variants, see const_assert_eq!() above
+					const _: () = assert!(DecoderMandatoryPrefix::PNP as u32 == 0);
+					const _: () = assert!(DecoderMandatoryPrefix::P66 as u32 == 1);
+					const _: () = assert!(DecoderMandatoryPrefix::PF3 as u32 == 2);
+					const _: () = assert!(DecoderMandatoryPrefix::PF2 as u32 == 3);
+					// SAFETY: 0<=(d&3)<=3 and those are valid enum variants, see const assert!() above
 					self.state.mandatory_prefix = unsafe { mem::transmute(d & 3) };
 
-					const_assert_eq!(StateFlags::W, 0x80);
+					const _: () = assert!(StateFlags::W == 0x80);
 					self.state.flags |= d & 0x80;
 
 					let p2 = d >> 8;
@@ -1927,9 +1867,9 @@ impl<'a> Decoder<'a> {
 					self.state.aaa = aaa;
 					instruction_internal::internal_set_op_mask(instruction, aaa);
 
-					const_assert_eq!(StateFlags::MVEX_SSS_SHIFT, 16);
-					const_assert_eq!(StateFlags::MVEX_SSS_MASK, 7);
-					const_assert_eq!(StateFlags::MVEX_EH, 1 << (StateFlags::MVEX_SSS_SHIFT + 3));
+					const _: () = assert!(StateFlags::MVEX_SSS_SHIFT == 16);
+					const _: () = assert!(StateFlags::MVEX_SSS_MASK == 7);
+					const _: () = assert!(StateFlags::MVEX_EH == 1 << (StateFlags::MVEX_SSS_SHIFT + 3));
 					self.state.flags |= (p2 & 0xF0) << (StateFlags::MVEX_SSS_SHIFT - 4);
 
 					let p1 = (!d >> 3) & 0x0F;
@@ -1968,11 +1908,11 @@ impl<'a> Decoder<'a> {
 	#[inline(always)]
 	fn read_op_seg_reg(&mut self) -> u32 {
 		let reg = self.state.reg;
-		const_assert_eq!(Register::ES as u32 + 1, Register::CS as u32);
-		const_assert_eq!(Register::ES as u32 + 2, Register::SS as u32);
-		const_assert_eq!(Register::ES as u32 + 3, Register::DS as u32);
-		const_assert_eq!(Register::ES as u32 + 4, Register::FS as u32);
-		const_assert_eq!(Register::ES as u32 + 5, Register::GS as u32);
+		const _: () = assert!(Register::ES as u32 + 1 == Register::CS as u32);
+		const _: () = assert!(Register::ES as u32 + 2 == Register::SS as u32);
+		const _: () = assert!(Register::ES as u32 + 3 == Register::DS as u32);
+		const _: () = assert!(Register::ES as u32 + 4 == Register::FS as u32);
+		const _: () = assert!(Register::ES as u32 + 5 == Register::GS as u32);
 		if reg < 6 {
 			Register::ES as u32 + reg
 		} else {
@@ -2123,10 +2063,10 @@ impl<'a> Decoder<'a> {
 			this.displ_index = this.data_ptr.wrapping_add(1) as u8;
 			let w = read_u16_break!(this) as u32;
 
-			const_assert_eq!(InstrScale::Scale1 as u32, 0);
-			const_assert_eq!(InstrScale::Scale2 as u32, 1);
-			const_assert_eq!(InstrScale::Scale4 as u32, 2);
-			const_assert_eq!(InstrScale::Scale8 as u32, 3);
+			const _: () = assert!(InstrScale::Scale1 as u32 == 0);
+			const _: () = assert!(InstrScale::Scale2 as u32 == 1);
+			const _: () = assert!(InstrScale::Scale4 as u32 == 2);
+			const _: () = assert!(InstrScale::Scale8 as u32 == 3);
 			// SAFETY: 0-3 are valid variants
 			instruction_internal::internal_set_memory_index_scale(instruction, unsafe { mem::transmute(((w >> 6) & 3) as InstrScaleUnderlyingType) });
 			let index = ((w >> 3) & 7) + this.state.extra_index_register_base;
@@ -2203,10 +2143,10 @@ impl<'a> Decoder<'a> {
 			this.displ_index = this.data_ptr as u8;
 			let displ = read_u32_break!(this) as i32 as u64;
 
-			const_assert_eq!(InstrScale::Scale1 as u32, 0);
-			const_assert_eq!(InstrScale::Scale2 as u32, 1);
-			const_assert_eq!(InstrScale::Scale4 as u32, 2);
-			const_assert_eq!(InstrScale::Scale8 as u32, 3);
+			const _: () = assert!(InstrScale::Scale1 as u32 == 0);
+			const _: () = assert!(InstrScale::Scale2 as u32 == 1);
+			const _: () = assert!(InstrScale::Scale4 as u32 == 2);
+			const _: () = assert!(InstrScale::Scale8 as u32 == 3);
 			// SAFETY: 0-3 are valid variants
 			instruction_internal::internal_set_memory_index_scale(instruction, unsafe { mem::transmute((sib >> 6) as InstrScaleUnderlyingType) });
 			let index = ((sib >> 3) & 7) + this.state.extra_index_register_base;
@@ -2263,10 +2203,10 @@ impl<'a> Decoder<'a> {
 	fn read_op_mem_0_4(instruction: &mut Instruction, this: &mut Decoder<'_>) -> bool {
 		loop {
 			let sib = read_u8_break!(this) as u32;
-			const_assert_eq!(InstrScale::Scale1 as u32, 0);
-			const_assert_eq!(InstrScale::Scale2 as u32, 1);
-			const_assert_eq!(InstrScale::Scale4 as u32, 2);
-			const_assert_eq!(InstrScale::Scale8 as u32, 3);
+			const _: () = assert!(InstrScale::Scale1 as u32 == 0);
+			const _: () = assert!(InstrScale::Scale2 as u32 == 1);
+			const _: () = assert!(InstrScale::Scale4 as u32 == 2);
+			const _: () = assert!(InstrScale::Scale8 as u32 == 3);
 			// SAFETY: 0-3 are valid variants
 			instruction_internal::internal_set_memory_index_scale(instruction, unsafe { mem::transmute((sib >> 6) as InstrScaleUnderlyingType) });
 			let index = ((sib >> 3) & 7) + this.state.extra_index_register_base;
@@ -2501,10 +2441,10 @@ fn decoder_read_op_mem_vsib_1_4(
 		write_index_reg!(instruction, index + this.state.extra_index_register_base_vsib + index_reg as u32);
 	}
 
-	const_assert_eq!(InstrScale::Scale1 as u32, 0);
-	const_assert_eq!(InstrScale::Scale2 as u32, 1);
-	const_assert_eq!(InstrScale::Scale4 as u32, 2);
-	const_assert_eq!(InstrScale::Scale8 as u32, 3);
+	const _: () = assert!(InstrScale::Scale1 as u32 == 0);
+	const _: () = assert!(InstrScale::Scale2 as u32 == 1);
+	const _: () = assert!(InstrScale::Scale4 as u32 == 2);
+	const _: () = assert!(InstrScale::Scale8 as u32 == 3);
 	// SAFETY: 0-3 are valid variants
 	instruction_internal::internal_set_memory_index_scale(instruction, unsafe { mem::transmute(((sib >> 6) & 3) as InstrScaleUnderlyingType) });
 	let base_reg = if this.state.address_size == OpSize::Size64 { Register::RAX } else { Register::EAX };
@@ -2572,10 +2512,10 @@ fn decoder_read_op_mem_vsib_2_4(
 		write_index_reg!(instruction, index + this.state.extra_index_register_base_vsib + index_reg as u32);
 	}
 
-	const_assert_eq!(InstrScale::Scale1 as u32, 0);
-	const_assert_eq!(InstrScale::Scale2 as u32, 1);
-	const_assert_eq!(InstrScale::Scale4 as u32, 2);
-	const_assert_eq!(InstrScale::Scale8 as u32, 3);
+	const _: () = assert!(InstrScale::Scale1 as u32 == 0);
+	const _: () = assert!(InstrScale::Scale2 as u32 == 1);
+	const _: () = assert!(InstrScale::Scale4 as u32 == 2);
+	const _: () = assert!(InstrScale::Scale8 as u32 == 3);
 	// SAFETY: 0-3 are valid variants
 	instruction_internal::internal_set_memory_index_scale(instruction, unsafe { mem::transmute((sib >> 6) as InstrScaleUnderlyingType) });
 
@@ -2617,10 +2557,10 @@ fn decoder_read_op_mem_vsib_0_4(
 	this: &mut Decoder<'_>, instruction: &mut Instruction, index_reg: Register, _tuple_type: TupleType, is_vsib: bool,
 ) -> bool {
 	let sib = this.read_u8() as u32;
-	const_assert_eq!(InstrScale::Scale1 as u32, 0);
-	const_assert_eq!(InstrScale::Scale2 as u32, 1);
-	const_assert_eq!(InstrScale::Scale4 as u32, 2);
-	const_assert_eq!(InstrScale::Scale8 as u32, 3);
+	const _: () = assert!(InstrScale::Scale1 as u32 == 0);
+	const _: () = assert!(InstrScale::Scale2 as u32 == 1);
+	const _: () = assert!(InstrScale::Scale4 as u32 == 2);
+	const _: () = assert!(InstrScale::Scale8 as u32 == 3);
 	// SAFETY: 0-3 are valid variants
 	instruction_internal::internal_set_memory_index_scale(instruction, unsafe { mem::transmute((sib >> 6) as InstrScaleUnderlyingType) });
 	let index = ((sib >> 3) & 7) + this.state.extra_index_register_base;
