@@ -12,7 +12,6 @@ use crate::*;
 use alloc::string::String;
 use alloc::vec::Vec;
 use core::mem;
-use static_assertions::const_assert_eq;
 
 #[derive(Debug)]
 pub(super) struct InstrOpInfo<'a> {
@@ -30,7 +29,7 @@ impl<'a> InstrOpInfo<'a> {
 		unsafe { mem::transmute(op_kind as u8) }
 	}
 
-	pub(super) fn op_register(&self, operand: u32) -> Register {
+	pub(super) const fn op_register(&self, operand: u32) -> Register {
 		self.op_registers[operand as usize]
 	}
 
@@ -92,7 +91,7 @@ impl<'a> InstrOpInfo<'a> {
 		}
 	}
 
-	pub(super) fn operand_index(&self, instruction_operand: u32) -> Option<u32> {
+	pub(super) const fn operand_index(&self, instruction_operand: u32) -> Option<u32> {
 		let index: i32 = if instruction_operand == self.op_indexes[0] as u32 {
 			0
 		} else if instruction_operand == self.op_indexes[1] as u32 {
@@ -128,7 +127,7 @@ impl<'a> InstrOpInfo<'a> {
 	fn new(mnemonic: &'a FormatterString, instruction: &Instruction, flags: u32) -> Self {
 		let mut res = InstrOpInfo::default(mnemonic);
 
-		const_assert_eq!(IcedConstants::MAX_OP_COUNT, 5);
+		const _: () = assert!(IcedConstants::MAX_OP_COUNT == 5);
 		res.flags = flags as u16;
 		let op_count = instruction.op_count();
 		res.op_count = op_count as u8;
@@ -267,10 +266,10 @@ pub(super) trait InstrInfo {
 
 fn get_bitness(code_size: CodeSize) -> u32 {
 	static CODESIZE_TO_BITNESS: [u32; 4] = [0, 16, 32, 64];
-	const_assert_eq!(CodeSize::Unknown as u32, 0);
-	const_assert_eq!(CodeSize::Code16 as u32, 1);
-	const_assert_eq!(CodeSize::Code32 as u32, 2);
-	const_assert_eq!(CodeSize::Code64 as u32, 3);
+	const _: () = assert!(CodeSize::Unknown as u32 == 0);
+	const _: () = assert!(CodeSize::Code16 as u32 == 1);
+	const _: () = assert!(CodeSize::Code32 as u32 == 2);
+	const _: () = assert!(CodeSize::Code64 as u32 == 3);
 	CODESIZE_TO_BITNESS[code_size as usize]
 }
 
@@ -406,7 +405,7 @@ impl InstrInfo for SimpleInstrInfo_nop {
 				unreachable!()
 			});
 			info.op_count = 2;
-			const_assert_eq!(InstrOpKind::Register as u32, 0);
+			const _: () = assert!(InstrOpKind::Register as u32 == 0);
 			//info.op_kinds[0] = InstrOpKind::Register;
 			//info.op_kinds[1] = InstrOpKind::Register;
 			info.op_registers[0] = self.register;
@@ -438,7 +437,7 @@ impl InstrInfo for SimpleInstrInfo_STIG1 {
 		debug_assert!(instruction.op0_kind() == OpKind::Register && instruction.op0_register() == Register::ST0);
 		if !self.pseudo_op || !(options.use_pseudo_ops() && instruction.op1_register() == Register::ST1) {
 			info.op_count = 1;
-			const_assert_eq!(InstrOpKind::Register as u32, 0);
+			const _: () = assert!(InstrOpKind::Register as u32 == 0);
 			//info.op_kinds[0] = InstrOpKind::Register;
 			info.op_registers[0] = instruction.op1_register();
 			info.op_indexes[0] = 1;
@@ -585,7 +584,7 @@ impl InstrInfo for SimpleInstrInfo_pblendvb {
 		let mut info = InstrOpInfo::default(&self.mnemonic);
 		debug_assert_eq!(instruction.op_count(), 2);
 		info.op_count = 3;
-		const_assert_eq!(InstrOpKind::Register as u32, 0);
+		const _: () = assert!(InstrOpKind::Register as u32 == 0);
 		//info.op_kinds[0] = InstrOpKind::Register;
 		info.op_registers[0] = Register::XMM0;
 		info.op_indexes[0] = InstrInfoConstants::OP_ACCESS_READ;
@@ -606,10 +605,10 @@ pub(super) struct SimpleInstrInfo_OpSize {
 
 impl SimpleInstrInfo_OpSize {
 	pub(super) fn new(code_size: CodeSize, mnemonic: String, mnemonic16: String, mnemonic32: String, mnemonic64: String) -> Self {
-		const_assert_eq!(CodeSize::Unknown as u32, 0);
-		const_assert_eq!(CodeSize::Code16 as u32, 1);
-		const_assert_eq!(CodeSize::Code32 as u32, 2);
-		const_assert_eq!(CodeSize::Code64 as u32, 3);
+		const _: () = assert!(CodeSize::Unknown as u32 == 0);
+		const _: () = assert!(CodeSize::Code16 as u32 == 1);
+		const _: () = assert!(CodeSize::Code32 as u32 == 2);
+		const _: () = assert!(CodeSize::Code64 as u32 == 3);
 		Self {
 			mnemonics: [
 				FormatterString::new(mnemonic),
@@ -640,10 +639,10 @@ pub(super) struct SimpleInstrInfo_OpSize2_bnd {
 
 impl SimpleInstrInfo_OpSize2_bnd {
 	pub(super) fn new(mnemonic: String, mnemonic16: String, mnemonic32: String, mnemonic64: String) -> Self {
-		const_assert_eq!(CodeSize::Unknown as u32, 0);
-		const_assert_eq!(CodeSize::Code16 as u32, 1);
-		const_assert_eq!(CodeSize::Code32 as u32, 2);
-		const_assert_eq!(CodeSize::Code64 as u32, 3);
+		const _: () = assert!(CodeSize::Unknown as u32 == 0);
+		const _: () = assert!(CodeSize::Code16 as u32 == 1);
+		const _: () = assert!(CodeSize::Code32 as u32 == 2);
+		const _: () = assert!(CodeSize::Code64 as u32 == 3);
 		Self {
 			mnemonics: [
 				FormatterString::new(mnemonic),
